"use strict";

var _replaceMarkdownParams = _interopRequireDefault(require("./replaceMarkdownParams"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * Author: Andrieiev Danil |  danssg08@gmail.com | https://github.com/DanilAndreev
 * Copyright (C) 2020.
 */
describe("Utils -> replaceMarkdownParams", function () {
  test("Replace single variable", function () {
    var source = "Hello darkness my &&text friend";
    var expected = "Hello darkness my old friend";
    expect((0, _replaceMarkdownParams.default)(source, {
      text: "old"
    })).toEqual(expected);
  });
  test("Replace variable inside codespan", function () {
    var source = "Hello darkness my ```&&text``` friend";
    var expected = "Hello darkness my ```old``` friend";
    expect((0, _replaceMarkdownParams.default)(source, {
      text: "old"
    })).toEqual(expected);
  });
  test("Replace multiple variables", function () {
    var source = "Hello __&&text1__ my ```&&text2``` friend";
    var expected = "Hello __darkness__ my ```old``` friend";
    expect((0, _replaceMarkdownParams.default)(source, {
      text1: "darkness",
      text2: "old"
    })).toEqual(expected);
  });
  test("Replace nested variables", function () {
    var source = "Hello darkness &&text friend";
    var expected = "Hello darkness my old friend";
    expect((0, _replaceMarkdownParams.default)(source, {
      text: "my &&nested",
      nested: "old"
    })).toEqual(expected);
  });
  test("Replace nested variables and locale", function () {
    var lang = {
      name: "en-us",
      label: "english",
      locale: {
        text1: "locale text1",
        nested: {
          text2: "locale text2"
        }
      }
    };
    var source = "Hello &{text1}& darkness &&text friend &{nested/text2}&";
    var expected = "Hello locale text1 darkness my old friend locale text2";
    expect((0, _replaceMarkdownParams.default)(source, {
      text: "my &&nested",
      nested: "old"
    }, lang)).toEqual(expected);
  });
  test("Test variable with no storage value.", function () {
    var source = "Hello darkness &&text friend";
    var expected = "Hello darkness &&text friend";
    expect((0, _replaceMarkdownParams.default)(source, {})).toEqual(expected);
  });
  test("Test screened locale.", function () {
    var source = "Hello darkness \&\{text\}\& friend";
    var expected = "Hello darkness &{text}& friend";
    expect((0, _replaceMarkdownParams.default)(source, {})).toEqual(expected);
  });
});